#!/bin/bash -xv
#
# Source : http://www.hping.org/hping3-20051105.tar.gz
# Maintainer : Son|c <emmanuel.bailleul@cegetel.net>
#


#------------------( Set Package Variables )


soft='hping3'
softversion='20051105'
packageversion='48.1'


#------------------( Set Architecture Variables )

arch='i486'
cpu='i686'


#------------------( Set Architecture Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Prepare The Work Area And Source Package )


cd $buildir
rm -f {$dest,$dest.dep,$dest.md5,$dest.tgz,$package,$package.md5,$src} 1>/dev/null 2>&1
tar -xvzf $srcpkg
mkdir -p $dest


#------------------( Set Build Ownerships, Permissions and CFLAGS )


    chown -R root:root . 
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu" 
export CXXFLAGS="$CFLAGS"


#------------------( Set Configuration Options )

cd $src
MANPATH=$dest/usr/man;./configure --no-tcl

#------------------( Apply some modifications to source and Makefile )

sed -i 's/\/usr\/sbin/$(DESTDIR)\/usr\/sbin/g' $src/Makefile
sed -i '/ln/d' $src/Makefile
sed -i 's/net\/bpf\.h/pcap-bpf\.h/g' $src/libpcap_stuff.c


#------------------( Make and Install Software )

make
mkdir -p $dest/usr/sbin
mkdir -p $dest/usr/man/man8
make install DESTDIR=$dest
#make install

#------------------ Strip Executables (Comment out these lines if debugging info is needed) )


cd $dest
chown -R root:root $dest
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)


#------------------( Copy Build The Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create and Install The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
    |-----handy-ruler------------------------------------------------------|
hping3: TCP/IP packet generator
hping3:
hping3: hping is a command-line oriented TCP/IP packet assembler/analyzer.
hping3: The interface is inspired to the ping(8) unix command, but hping
hping3: isn't only able to send ICMP echo requests. It supports TCP, UDP,
hping3: ICMP and RAW-IP protocols, has a traceroute mode, the ability to
hping3: send files between a covered channel, and many other features
hping3:
hping3:
hping3:
hping3:
EOF


#------------------( Compress Man Pages )

( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)


#------------------( Create The *.dep File )


cd $dest
requiredbuilder -z $dest > $buildir/$package.dep

#------------------( Compress The Package And Clean Up The Work Area )


cd $dest
makepkg -l n -c n $package.tgz
mv $package.tgz ../$package.tgz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
rm -f $package.md5
md5sum $package.tgz > $package.md5

